Learn R Programming

L1centrality (version 0.4.0)

L1centrality-package: L1centrality: Graph/Network Analysis Based on L1 Centrality

Description

Analyze graph/network data using L1 centrality and prestige. Functions for deriving global, local, and group L1 centrality/prestige are provided. Routines for visual inspection of a graph/network are also provided. Details are in Kang and Oh (2025a,b) and Kang (2025).

Arguments

Author

Maintainer: Seungwoo Kang kangsw0401@snu.ac.kr (ORCID)

Authors:

Details

Every function inside this package supports a distinct variety of graphs. Edge weights can be considered by all functions. Additionally, it is assumed that the graph to be analyzed is a connected graph in the case of an undirected graph, or a strongly connected graph in the case of a directed graph.

Certain functions exclusively accommodate undirected graphs without vertex multiplicity, while others support both directed and undirected graphs with vertex multiplicities. The following table provides a concise overview of the support range for each function.

FunctionsUndirected graphDirected graphVertex multiplicity
L1cent(), L1centNB(), L1centLOC(), L1centGROUP()OOO
L1centEDGE()OXO
L1centMDS()OXX

References

S. Kang. Topics in Non-Euclidean Dimension Reduction. PhD thesis, Seoul National University, 2025.

S. Kang and H.-S. Oh. On a notion of graph centrality based on L1 data depth. Journal of the American Statistical Association, 1--13, 2025a.

S. Kang and H.-S. Oh. L1 prominence measures for directed graphs. The American Statistician, 1--16, 2025b.

See Also