Network between 32 movies from the Marvel Cinematic Universe (MCU) that were released between 2008 and 2023. Each movie represents one vertex.
An edge between movies i and j is formed if there is at least one cast in common. Denoting the set of casts of movie i as Ai, the weight of this edge is given as (|Ai\(\cap\)Aj|/|Ai\(\cup\)Aj|)-1, where \(|\cdot|\) denotes the cardinality of a set.
data(MCUmovie)An undirected, connected, and (edge) weighted igraph graph object with 32
vertices and 278 edges.
Vertex attributes:
‘name’: name of the movie. e.g., Guardians of the Galaxy Vol. 3.
‘worldwidegross’: worldwide gross in USD. Archived from IMDb on Nov. 3rd, 2023.
‘year’: release year of the movie.
Edge attribute: ‘weight’. Given as a dissimilarity between two vertices. See the description above.
G. Choi and H.-S. Oh. Heavy-snow transform: A new method for graph signals. Manuscript, 2021.
S. Kang and H.-S. Oh. On a notion of graph centrality based on L1 data depth. Journal of the American Statistical Association, 1--13, 2025.