Derives a multiscale edge representation. Each vertex is connected to its local median, which is found in its L1 centrality-based neighborhood.
L1centEDGE(g, eta, alpha, weight_transform)# S3 method for igraph
L1centEDGE(g, eta = NULL, alpha, weight_transform = NULL)
# S3 method for matrix
L1centEDGE(g, eta = NULL, alpha, weight_transform = NULL)
# S3 method for L1centEDGE
print(x, ...)
# S3 method for L1centEDGE
plot(x, ...)
# S3 method for L1centEDGE
summary(object, ...)
L1centEDGE() returns an object of class L1centEDGE. It
is a list of ‘edge lists’. The length of the list is equivalent to
the length of alpha, and the names of the list are the values of
alpha. The ith component of the list is a 2-column matrix,
and each row defines one directed edge, i.e., it is an edge list. The
second column is the local (level alpha[i]) median of the vertex at
the first column. There may be more than one edge from each vertex, since
there may be more than one local median.
print.L1centEDGE() prints the edge lists and returns them invisibly.
plot.L1centEDGE() draws directed graphs corresponding to each value
of alpha. In each display, each vertex gives a directed edge to its
local median vertex. The local median vertices are shown with larger
circles.
summary.L1centEDGE() returns an object of class table with the
number of local medians at each locality level alpha.
An igraph graph object or a distance matrix. The graph must
be undirected and connected. Equivalently, the distance matrix must be
symmetric, and all entries must be finite.
An optional nonnegative multiplicity (weight) vector for (vertex)
weighted networks. The sum of its components must be positive. If set to
NULL (the default), all vertices will have the same positive weight
(multiplicity) of 1, i.e., g is treated as a vertex unweighted graph. The
length of the eta must be equivalent to the number of vertices.
A number or a numeric vector of locality levels. Values must be between 0 and 1.
An optional function to transform the edge weights
when g is an igraph object and an edge weight attribute exists. This
argument is ignored when g is a distance matrix.
An L1centEDGE object, obtained as a result of the function
L1centEDGE().
Further arguments passed to or from other methods.
plot() method: Further graphical parameters supplied to the internal
igraph::plot.igraph() function. See igraph::plot.common document.
print() and summary() methods: Further arguments passed to the
base::print() and base::summary() functions, respectively.
An L1centEDGE object, obtained as a result of the function
L1centEDGE().
In a global perspective, any given undirected graph can be represented as a star-shaped directed graph, with each vertex making a connection to the median vertex. Based on this idea, an undirected graph can be represented as a directed graph, with each vertex making a connection to the local median vertex. The local median vertex of, say, \(v_i\), is defined as a median vertex among the L1 centrality-based neighborhood of \(v_i\). By varying the level of locality, the given graph can be visually inspected at multiple scales. Refer to Kang and Oh (2025) for details.
S. Kang and H.-S. Oh. On a notion of graph centrality based on L1 data depth. Journal of the American Statistical Association, 1--13, 2025.
L1cent(), L1centNB(), L1centLOC().
library(igraph)
MCU_edge <- L1centEDGE(MCUmovie, eta = V(MCUmovie)$worldwidegross, alpha = 5/32)
plot(MCU_edge)
Run the code above in your browser using DataLab